Chat History Formatting Example
================================

This example demonstrates how to format and export conversation history.

.. literalinclude:: ../../../examples/chat_formatting_demo.py
   :language: python
   :linenos:

